@@ -1,20 +1,25 @@
 
-/***************************************************************************
-                          nodeview_cmds.c  - node viewing commands for xsldbg
-                             -------------------
-    begin                : Wed Nov 21 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 #include "xsldbg.h"
 #include <libxml/xpathInternals.h>
@@ -36,35 +41,34 @@
 static xmlChar nodeViewBuffer[500];
 static int printVariableValue = 0;
 
-/*
- * xslDbgShellPrintNames:
+/**
  * Print a name of variable found by scanning variable table
  * It is used by print_variable function.
- * @payload : not used
- * @data : not used
- * @name : the variable name 
+ *
+ * @param payload : not used
+ * @param data : not used
+ * @param name : the variable name 
  */
 void *xslDbgShellPrintNames(void *payload,
                             void *data, xmlChar * name);
 
 /**
- * xslDbgCatToFile:
- * @node : Is valid
- * @file : Is valid
- *
  * Send the results of cat command in @node to @file
+ *
+ * @param node : Is valid
+ * @param file : Is valid
+ *
  */
 static void xslDbgCatToFile(xmlNodePtr node, FILE * file);
 
 
 /**
- * printXPathObject:
- * @item :  XPath object to print
- * @xPath : The XPath used to find item
- *
  * Print an XPath object
  *
- * Returns 1 on success,
+ * @param item :  XPath object to print
+ * @param xPath : The XPath used to find item
+ *
+ * @returns 1 on success,
  *         0 otherwise
  */
 static int printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath);
@@ -74,20 +78,7 @@ static int printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath);
 ---------------------------------------*/
 
 
-/**
- * xslDbgShellPrintList: 
- * @ctxt: The current shell context
- * @arg: What xpath to display and in UTF-8
- * @dir: If 1 print in dir mode?, 
- *        otherwise ls mode
- *
- * Print list of nodes in either ls or dir format
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgShellPrintList(xmlShellCtxtPtr ctxt, xmlChar * arg, int dir)
+int xslDbgShellPrintList(xmlShellCtxtPtr ctxt, xmlChar * arg, int dir)
 {
     xmlXPathObjectPtr list;
     int result = 0;
@@ -137,7 +128,7 @@ xslDbgShellPrintList(xmlShellCtxtPtr ctxt, xmlChar * arg, int dir)
             }
             xmlXPathFreeObject(list);
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n", xsldbgText(arg)));
         }
         ctxt->pctxt->node = NULL;
     }
@@ -146,15 +137,7 @@ xslDbgShellPrintList(xmlShellCtxtPtr ctxt, xmlChar * arg, int dir)
 
 
 
-/**
- * xslDbgCatToFile:
- * @node : Is valid
- * @file : Is valid
- *
- * Send the results of cat command in @node to @file
- */
-void
-xslDbgCatToFile(xmlNodePtr node, FILE * file)
+void xslDbgCatToFile(xmlNodePtr node, FILE * file)
 {
     if (!node || !file)
       return;
@@ -172,7 +155,7 @@ xslDbgCatToFile(xmlNodePtr node, FILE * file)
         const xmlChar *encoding = doc->encoding;
 
         if (encoding) {
-            xsldbgGenericErrorFunc(i18n("Information: Temporarily setting document's encoding to UTF-8. Previously was %1.\n").arg(xsldbgText(encoding)));
+            xsldbgGenericErrorFunc(i18n("Information: Temporarily setting document's encoding to UTF-8. Previously was %1.\n", xsldbgText(encoding)));
         }
         doc->encoding = (xmlChar *) "UTF-8";
         xmlDocDump(file, (xmlDocPtr) node);
@@ -183,19 +166,8 @@ xslDbgCatToFile(xmlNodePtr node, FILE * file)
 }
 
 
-/**
- * printXPathObject:
- * @item :  XPath object to print
- * @xPath : The XPath used to find item
- *
- * Print an XPath object
- *
- * Returns 1 on success,
- *         0 otherwise
- */
 
-static int
-printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
+static int printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
   int result = 0;
   if (item){ 
     switch (item->type) {
@@ -226,7 +198,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 	  break;
 	file = fopen(fileName, "w+");
 	if (!file) {
-	   xsldbgGenericErrorFunc(i18n("Error: Unable to save temporary results to %1.\n").arg(xsldbgText(fileName)));
+	   xsldbgGenericErrorFunc(i18n("Error: Unable to save temporary results to %1.\n", xsldbgText(fileName)));
 	  break;
 	} else {
 	  fprintf(file, "= %s\n", xPath);
@@ -240,7 +212,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 						nodeTab[indx], file);
 	      }
 	    } else {
-	      xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(xPath)));
+	      xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n", xsldbgText(xPath)));
 	    }
 	    break;
 			     
@@ -248,7 +220,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 	    if (item->stringval)
 	      fprintf(file, "\'%s\'", item->stringval);
 	    else
-	      fprintf(file, "%s", i18n("NULL string value supplied.").utf8().data());
+	      fprintf(file, "%s", i18n("NULL string value supplied.").toUtf8().constData());
 	    break;
 			     
 	  default:{
@@ -259,7 +231,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 	      if (tempObj && tempObj->stringval){
 		fprintf(file, "%s", tempObj->stringval);
 	      }else{
-		fprintf(file, "%s", i18n("Unable to convert XPath to string.").utf8().data());	
+		fprintf(file, "%s", i18n("Unable to convert XPath to string.").toUtf8().constData());	
 	      }
 	      if (tempObj)
 		xmlXPathFreeObject(tempObj);
@@ -319,21 +291,8 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 }
 
 
-/** 
- * xslDbgShellCat:
- * @styleCtxt: the current stylesheet context
- * @ctxt: The current shell context
- * @arg: The xpath to print (in UTF-8)
- *
- * Print the result of an xpath expression. This can include variables
- *        if styleCtxt is not NULL
- *
- * Returns 1 on success,
- *         0 otherwise
- */
 
-int
-xslDbgShellCat(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
+int xslDbgShellCat(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                xmlChar * arg)
 {
     xmlXPathObjectPtr list;
@@ -380,7 +339,7 @@ xslDbgShellCat(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
         result = printXPathObject(list, arg);
         xmlXPathFreeObject(list);
     } else {
-        xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(arg)));
+        xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n", xsldbgText(arg)));
     }
     ctxt->pctxt->node = NULL;
     return result;
@@ -389,16 +348,8 @@ xslDbgShellCat(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
 /* only used by xslDbgPrintNames and xslDbgPrintVariable cound number of variables */
 static int varCount;
 
-/*
- * xslDbgShellPrintNames:
- * Print a name of variable found by scanning variable table
- * It is used by print_variable function.
- * @payload : Global variable of type xsltStackElemPtr
- * @data : not used
- * @name : the variable name 
- */
-void *
-xslDbgShellPrintNames(void *payload,
+
+void * xslDbgShellPrintNames(void *payload,
                       void *data, xmlChar * name)
 {
     Q_UNUSED(payload);
@@ -415,19 +366,19 @@ xslDbgShellPrintNames(void *payload,
 		     item->nameURI, item->name);
 	}
         if (printVariableValue == 0){
-	    xsldbgGenericErrorFunc(i18n(" Global %1\n").arg(xsldbgText(fullQualifiedName)));
+	    xsldbgGenericErrorFunc(i18n(" Global %1\n", xsldbgText(fullQualifiedName)));
         }else{
 	      if (item->computed == 1){
 	         xsldbgGenericErrorFunc(i18n(" Global "));
 		 printXPathObject(item->value, fullQualifiedName);
 	      }else if (item->tree){
-	         xsldbgGenericErrorFunc(i18n(" Global = %1\n").arg(xsldbgText(fullQualifiedName)));
+	         xsldbgGenericErrorFunc(i18n(" Global = %1\n", xsldbgText(fullQualifiedName)));
 		 xslDbgCatToFile(item->tree, stderr);
 	      }else if (item->select){
-	         xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(xsldbgText(item->select)));
+	         xsldbgGenericErrorFunc(i18n(" Global = %1\n%2", xsldbgText(fullQualifiedName), xsldbgText(item->select)));
 	      }else{
 		/* can't find a value give only a variable name an error message */
-		xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(i18n("Warning: No value assigned to variable.\n")));
+		xsldbgGenericErrorFunc(i18n(" Global = %1\n%2", xsldbgText(fullQualifiedName), i18n("Warning: No value assigned to variable.\n")));
 	      }
 	    xsltGenericError(xsltGenericErrorContext, "\n\032\032\n");
         }
@@ -438,19 +389,7 @@ xslDbgShellPrintNames(void *payload,
 
 
 
-/**
- * xslDbgShellPrintVariable:
- * @styleCtxt: The current stylesheet context 
- * @arg: The name of variable to look for '$' prefix is optional and in UTF-8
- * @type: A valid VariableTypeEnum
- *
- *  Print the value variable specified by args.
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgShellPrintVariable(xsltTransformContextPtr styleCtxt, xmlChar * arg,
+int xslDbgShellPrintVariable(xsltTransformContextPtr styleCtxt, xmlChar * arg,
                          VariableTypeEnum type)
 {
     int result = 0;
@@ -527,47 +466,50 @@ xslDbgShellPrintVariable(xsltTransformContextPtr styleCtxt, xmlChar * arg,
             }
         } else {
             /* list local variables */
-            if (styleCtxt->varsBase) {
-                xsltStackElemPtr item =
-                    styleCtxt->varsTab[styleCtxt->varsBase];
-                if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
-                    notifyListStart(XSLDBG_MSG_LOCALVAR_CHANGED);
-                    while (item) {
-                        notifyListQueue(item);
-                        item = item->next;
-                    }
-                    notifyListSend();
+            if (styleCtxt->varsNr && styleCtxt->varsBase) {
+		if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+		    notifyListStart(XSLDBG_MSG_LOCALVAR_CHANGED);
+		    for (int i = styleCtxt->varsNr; i > styleCtxt->varsBase; i--) {
+                        xsltStackElemPtr item = styleCtxt->varsTab[i-1];
+                        while (item) {
+                            notifyListQueue(item);
+                            item = item->next;
+                        }
+		    }
+		    notifyListSend();
                 } else {
 		    xmlChar * fullQualifiedName = nodeViewBuffer;
-                    while (item) {		      
-                        if (item->name) {			     
-			    if (item->nameURI == NULL){
-				snprintf((char*)fullQualifiedName, sizeof(nodeViewBuffer), "$%s",
-					 item->name);
-			    }else{
-
-				snprintf((char*)fullQualifiedName, sizeof(nodeViewBuffer), "$%s:%s",
-					 item->nameURI, item->name);
-			    }
-			    if (printVariableValue == 0){
-				xsldbgGenericErrorFunc(i18n(" Local %1").arg(xsldbgText(fullQualifiedName)));
-			    }else{
-			        if (item->computed == 1){
-			           xsldbgGenericErrorFunc(i18n(" Local "));
-			           printXPathObject(item->value, fullQualifiedName);
-			        }else if (item->tree){
-			           xsldbgGenericErrorFunc(i18n(" Local = %1\n").arg(xsldbgText(fullQualifiedName)));
-			           xslDbgCatToFile(item->tree, stderr);
-			        }else if (item->select){
-				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(xsldbgText(item->select)));
-				}else{
-				  /* can't find a value give only a variable name and an error */
-				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(i18n("Warning: No value assigned to variable.\n")));
-				}
-			    }
-			    xsltGenericError(xsltGenericErrorContext, "\n\032\032\n");
-			}
-                        item = item->next;
+		    for (int i = styleCtxt->varsNr; i > styleCtxt->varsBase; i--) {
+                        xsltStackElemPtr item = styleCtxt->varsTab[i-1];
+                        while (item) {		      
+                            if (item->name) {			     
+                                if (item->nameURI == NULL){
+                                    snprintf((char*)fullQualifiedName, sizeof(nodeViewBuffer), "$%s",
+                                                    item->name);
+                                }else{
+                                    snprintf((char*)fullQualifiedName, sizeof(nodeViewBuffer), "$%s:%s",
+                                                    item->nameURI, item->name);
+                                }
+                                if (printVariableValue == 0){
+                                    xsldbgGenericErrorFunc(i18n(" Local %1", xsldbgText(fullQualifiedName)));
+                                }else{
+                                    if (item->computed == 1){
+                                        xsldbgGenericErrorFunc(i18n(" Local "));
+                                        printXPathObject(item->value, fullQualifiedName);
+                                    }else if (item->tree){
+                                        xsldbgGenericErrorFunc(i18n(" Local = %1\n", xsldbgText(fullQualifiedName)));
+                                        xslDbgCatToFile(item->tree, stderr);
+                                    }else if (item->select){
+                                        xsldbgGenericErrorFunc(i18n(" Local = %1\n%2", xsldbgText(fullQualifiedName), xsldbgText(item->select)));
+                                    }else{
+                                        /* can't find a value give only a variable name and an error */
+                                        xsldbgGenericErrorFunc(i18n(" Local = %1\n%2", xsldbgText(fullQualifiedName), i18n("Warning: No value assigned to variable.\n")));
+                                    }
+                                }
+                                xsltGenericError(xsltGenericErrorContext, "\n\032\032\n");
+                                }
+                            item = item->next;
+                        }
 		    }
                 }
                 result = 1;
