@@ -96,7 +96,7 @@ int xslDbgShellSetOption(xmlChar * arg)
                             break;
 
                         default:
-                            xsldbgGenericErrorFunc(i18n("Information: The new value for option \'%1\' will not be applied until the run command is used\n.",
+                            xsldbgGenericErrorFunc(i18n("Information: The new value for option \'%1\' will not be applied until the run command is used.\n",
                                         xsldbgText(opts[0])));
                             break;
                     }
