@@ -1,20 +1,25 @@
 
-/***************************************************************************
-                          xsldbgmsg.h  -  description
-                             -------------------
-    begin                : Thu Dec 20 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef XSLDBGMSG_H
 #define XSLDBGMSG_H
@@ -27,10 +32,8 @@
 #  endif
 #endif
 
-#ifndef BUILD_DOCS
 #include <libxml/tree.h>        /* needed for the definition of xmlChar */
 #include "arraylist.h"
-#endif
 
 typedef enum {
     /* thread status */
@@ -46,7 +49,7 @@ typedef enum {
     XSLDBG_MSG_PROCESSING_INPUT,        /* 7: Processing user's request */
 
     /* provide more informatiom about state of xsldbg (optional) */
-    XSLDBG_MSG_PROCESSING_RESULT,       /* 8: An error occured performing command
+    XSLDBG_MSG_PROCESSING_RESULT,       /* 8: An error occurred performing command
                                          * requested command */
     XSLDBG_MSG_LINE_CHANGED,    /* 9: Changed to new line number
                                  * ie a step */
@@ -54,13 +57,13 @@ typedef enum {
     XSLDBG_MSG_BREAKPOINT_CHANGED,      /* 11: Response to a showbreak command */
     XSLDBG_MSG_PARAMETER_CHANGED,       /* 12: Response to showparam command */
     XSLDBG_MSG_TEXTOUT,         /* 13 : Free form text from xsldg */
-    XSLDBG_MSG_FILEOUT,         /* 14 : Response to cat commmand, ie
+    XSLDBG_MSG_FILEOUT,         /* 14 : Response to cat command, ie
                                  * Free form text in file */
     XSLDBG_MSG_LOCALVAR_CHANGED,        /* 15 : Response to locals command ie a
                                          * local variable */
     XSLDBG_MSG_GLOBALVAR_CHANGED,       /* 16 : Response to globals command
                                          * ie a global variable */
-    XSLDBG_MSG_TEMPLATE_CHANGED,        /* 17 : Response to templates commmand
+    XSLDBG_MSG_TEMPLATE_CHANGED,        /* 17 : Response to templates command
                                          * ie template details */
     XSLDBG_MSG_SOURCE_CHANGED,  /* 18 : Response to stylesheets command,
                                  * a normal stylesheet */
@@ -143,9 +146,9 @@ typedef enum {
  *     NULL then that indicates the start of a list of values
  *
  *<pre>
- * @returns 1 on sucess
+ * @returns 1 on success
  *          0 otherwise
-*/
+ */
 
 typedef struct _xsldbgErrorMsg xsldbgErrorMsg;
 typedef xsldbgErrorMsg *xsldbgErrorMsgPtr;
@@ -165,15 +168,12 @@ struct _notifyMessageList {
     arrayListPtr list;
 };
 
-#ifdef __cplusplus
-extern "C" {
-#endif
 
 void xsldbgSetAppFunc(int (*notifyXsldbgAppFunc) (XsldbgMessageEnum type, const void *data));
 
 void xsldbgSetAppStateFunc(int (*notifyStateXsldbgAppFunc)(XsldbgMessageEnum type, int commandId,
-                             XsldbgCommandStateEnum commandState,
-                             const char *text));
+            XsldbgCommandStateEnum commandState,
+            const char *text));
 
 void xsldbgSetTextFunc(int (*notifyTextXsldbgAppFunc)(XsldbgMessageEnum type, const char *text));
 
@@ -182,29 +182,26 @@ void xsldbgSetReadlineFunc(xmlChar * (*xslDbgShellReadlineFunc)(xmlChar * prompt
 int notifyXsldbgApp(XsldbgMessageEnum type, const void *data);
 
 int notifyStateXsldbgApp(XsldbgMessageEnum type, int commandId,
-                             XsldbgCommandStateEnum commandState,
-                             const char *text);
+        XsldbgCommandStateEnum commandState,
+        const char *text);
 
 int notifyTextXsldbgApp(XsldbgMessageEnum type, const char *text);
 
 xmlChar * xslDbgShellReadline(xmlChar * prompt);
 
 
-    /* The following functions implemented in xsldbgthread.c */
-	int notifyListStart(XsldbgMessageEnum type);
+/* The following functions implemented in xsldbgthread.c */
+int notifyListStart(XsldbgMessageEnum type);
 
-    /* Data must be valid for until the next notifyListStart.
-     * Memory pointed to by @data will not be freed. Added @data items
-     * queued to list must be of the same data type as required by the
-     * XsldbgMessageEnum used with the matching notifyListSend */
-    int notifyListQueue(const void *data);
+/* Data must be valid for until the next notifyListStart.
+ * Memory pointed to by @data will not be freed. Added @data items
+ * queued to list must be of the same data type as required by the
+ * XsldbgMessageEnum used with the matching notifyListSend */
+int notifyListQueue(const void *data);
 
-    /* The notified application is responsible for free memory used
-     * by the ArrayList and notifyMessageList of notify message */
-    int notifyListSend(void);
+/* The notified application is responsible for free memory used
+ * by the ArrayList and notifyMessageList of notify message */
+int notifyListSend(void);
 
 
-#ifdef __cplusplus
-}
-#endif
 #endif
