@@ -7,17 +7,16 @@
  *                                                                         										*
  ************************************************************************************/
 
-#ifndef XSLDBMSGDIALOGIMPL_H
-#define XSLDBMSGDIALOGIMPL_H
+#ifndef XSLDBGMSGDIALOGIMPL_H
+#define XSLDBGMSGDIALOGIMPL_H
 
 /**
   *@author Keith Isdale
   */
 
-#include "xsldbgmsgdialog.h"
-#include <qtextedit.h>
+#include "ui_xsldbgmsgdialog.h"
 
-class XsldbgMsgDialogImpl : public XsldbgMsgDialog {
+class XsldbgMsgDialogImpl : public QDialog, Ui::XsldbgMsgDialog {
 
 public:
 
@@ -27,4 +26,5 @@ public:
 
   void append(const QString &text);
 };
-#endif
+
+#endif // XSLDBGMSGDIALOGIMPL_H
